JaSerializer.ContentTypeNegotiation
This plug provides content type negotiation by validating the
content-type and accept headers.
The proper jsonapi.org content type is: application/vnd.api+json.
As per the spec this plug does three things.
- Returns 415 unless the content-type header is correct.
- Returns 406 unless the accept header is correct.
- Registers a before send hook to set the content-type if not already set.
Usage
Just include in your plug stack:
plug JaSerializer.ContentTypeNegotiation
Summary
| call(conn, opts) | Callback implementation for |
| init(opts) | Callback implementation for |
| set_content_type(conn, opts) | |
| verify_accepts(conn, opts) | |
| verify_content_type(conn, o) |
Functions
Callback implementation for c:Plug.call/2.
Callback implementation for c:Plug.init/1.